==> qtjambi-webenginewidgets-5.15.15-sources.jar: io/qt/webengine/widgets/QWebEngineHistoryItem.java <==
package io.qt.webengine.widgets;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class QWebEngineHistoryItem</p>
 */
public class QWebEngineHistoryItem extends QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public QWebEngineHistoryItem(io.qt.webengine.widgets.@NonNull QWebEngineHistoryItem other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QWebEngineHistoryItem instance, io.qt.webengine.widgets.QWebEngineHistoryItem other);
    
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl iconUrl(){
        return iconUrl_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QUrl iconUrl_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final boolean isValid(){
        return isValid_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean isValid_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final io.qt.core.@NonNull QDateTime lastVisited(){
        return lastVisited_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QDateTime lastVisited_native_constfct(long __this__nativeId);
    
    /**
     * @deprecated Use {@link #assign(io.qt.webengine.widgets.QWebEngineHistoryItem)} instead.
     */
    @Deprecated
    @QtUninvokable
    public final void set(io.qt.webengine.widgets.@NonNull QWebEngineHistoryItem other) {
        assign(other);
    }
    
    @QtUninvokable
    public final void assign(io.qt.webengine.widgets.@NonNull QWebEngineHistoryItem other){
        assign_native_cref_QWebEngineHistoryItem(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QWebEngineHistoryItem(long __this__nativeId, long other);
    
    @QtUninvokable
    private final boolean operator_equal(io.qt.webengine.widgets.@NonNull QWebEngineHistoryItem arg2){
        return operator_equal_native_cref_QWebEngineHistoryItem(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg2));
    }
    
    @QtUninvokable
    private native boolean operator_equal_native_cref_QWebEngineHistoryItem(long __this__nativeId, long arg2);
    
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl originalUrl(){
        return originalUrl_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QUrl originalUrl_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final void swap(io.qt.webengine.widgets.@StrictNonNull QWebEngineHistoryItem other){
        java.util.Objects.requireNonNull(other, "Argument 'other': null not expected.");
        swap_native_ref_QWebEngineHistoryItem(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native void swap_native_ref_QWebEngineHistoryItem(long __this__nativeId, long other);
    
    @QtUninvokable
    public final java.lang.@NonNull String title(){
        return title_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String title_native_constfct(long __this__nativeId);
    
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl url(){
        return url_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QUrl url_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QWebEngineHistoryItem(QPrivateConstructor p) { super(p); } 
    

    @Override
    @QtUninvokable
    public boolean equals(Object other) {
        if (other instanceof io.qt.webengine.widgets.QWebEngineHistoryItem) {
            return operator_equal((io.qt.webengine.widgets.QWebEngineHistoryItem) other);
        }

        return false;
    }


    @QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QWebEngineHistoryItem clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QWebEngineHistoryItem clone_native(long __this_nativeId);
}

==> qtjambi-webenginewidgets-5.15.17-sources.jar: io/qt/webengine/widgets/QWebEngineHistoryItem.java <==
package io.qt.webengine.widgets;

import io.qt.*;


/**
 * <p>Java wrapper for Qt class <code>QWebEngineHistoryItem</code></p>
 */
public class QWebEngineHistoryItem extends QtObject
    implements java.lang.Cloneable
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>QWebEngineHistoryItem::<wbr>QWebEngineHistoryItem(QWebEngineHistoryItem)</code></p>
     */
    public QWebEngineHistoryItem(io.qt.webengine.widgets.@NonNull QWebEngineHistoryItem other){
        super((QPrivateConstructor)null);
        initialize_native(this, other);
    }
    
    private native static void initialize_native(QWebEngineHistoryItem instance, io.qt.webengine.widgets.QWebEngineHistoryItem other);
    
    /**
     * <p>See <code>QWebEngineHistoryItem::<wbr>iconUrl()const</code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl iconUrl(){
        return iconUrl_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QUrl iconUrl_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineHistoryItem::<wbr>isValid()const</code></p>
     */
    @QtUninvokable
    public final boolean isValid(){
        return isValid_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean isValid_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineHistoryItem::<wbr>lastVisited()const</code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QDateTime lastVisited(){
        return lastVisited_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QDateTime lastVisited_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineHistoryItem::<wbr>operator=(QWebEngineHistoryItem)</code></p>
     */
    @QtUninvokable
    public final void assign(io.qt.webengine.widgets.@NonNull QWebEngineHistoryItem other){
        assign_native_cref_QWebEngineHistoryItem(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native void assign_native_cref_QWebEngineHistoryItem(long __this__nativeId, long other);
    
    /**
     * <p>See <code>operator==(QWebEngineHistoryItem,<wbr>QWebEngineHistoryItem)</code></p>
     */
    @QtUninvokable
    private final boolean operator_equal(io.qt.webengine.widgets.@NonNull QWebEngineHistoryItem arg2){
        return operator_equal_native_cref_QWebEngineHistoryItem(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(arg2));
    }
    
    @QtUninvokable
    private native boolean operator_equal_native_cref_QWebEngineHistoryItem(long __this__nativeId, long arg2);
    
    /**
     * <p>See <code>QWebEngineHistoryItem::<wbr>originalUrl()const</code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl originalUrl(){
        return originalUrl_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QUrl originalUrl_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineHistoryItem::<wbr>swap(QWebEngineHistoryItem&amp;)</code></p>
     */
    @QtUninvokable
    public final void swap(io.qt.webengine.widgets.@StrictNonNull QWebEngineHistoryItem other){
        java.util.Objects.requireNonNull(other, "Argument 'other': null not expected.");
        swap_native_ref_QWebEngineHistoryItem(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(other));
    }
    
    @QtUninvokable
    private native void swap_native_ref_QWebEngineHistoryItem(long __this__nativeId, long other);
    
    /**
     * <p>See <code>QWebEngineHistoryItem::<wbr>title()const</code></p>
     */
    @QtUninvokable
    public final java.lang.@NonNull String title(){
        return title_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String title_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>QWebEngineHistoryItem::<wbr>url()const</code></p>
     */
    @QtUninvokable
    public final io.qt.core.@NonNull QUrl url(){
        return url_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native io.qt.core.QUrl url_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QWebEngineHistoryItem(QPrivateConstructor p) { super(p); } 
    

    /**
     * <p>See <code>operator==(QWebEngineHistoryItem,<wbr>QWebEngineHistoryItem)</code></p>
     */
    @Override
    @QtUninvokable
    public boolean equals(Object other) {
        if (other instanceof io.qt.webengine.widgets.QWebEngineHistoryItem) {
            return operator_equal((io.qt.webengine.widgets.QWebEngineHistoryItem) other);
        }

        return false;
    }


    /**
     * Returns the objects's hash code computed by <code>qHash(QWebEngineHistoryItem)</code>.
     */
    @QtUninvokable
    @Override
    public int hashCode() {
        return hashCode_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    @QtUninvokable
    private native static int hashCode_native(long __this_nativeId);
    
    /**
     * <p>Creates and returns a copy of this object.</p>
     */
    @QtUninvokable
    @Override
    public QWebEngineHistoryItem clone() {
        return clone_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    private static native QWebEngineHistoryItem clone_native(long __this_nativeId);
    
    /**
     * @deprecated Use {@link #assign(io.qt.webengine.widgets.QWebEngineHistoryItem)} instead.
     */
    @Deprecated
    @QtUninvokable
    public final void set(io.qt.webengine.widgets.@NonNull QWebEngineHistoryItem other) {
        assign(other);
    }
}
